# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

from cmf.monitor import jmx_beans
from cmf.monitor.json_metrics_utils import get_beans

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what we expect.
    """
    self._json = json_dict
    beans = get_beans(self._json, set([jmx_beans.DATANODE,
                                       jmx_beans.DATANODE_DATASET_STATE,
                                       jmx_beans.DATANODE_JVM_METRICS,
                                       jmx_beans.JAVA_MEMORY]))
    self.datanode = beans.get(jmx_beans.DATANODE)
    self.datanode_dataset_state = beans.get(jmx_beans.DATANODE_DATASET_STATE)
    self.jvm = beans.get(jmx_beans.DATANODE_JVM_METRICS)
    self.java_memory = beans.get(jmx_beans.JAVA_MEMORY)

#
# This is what the DN json looks like:
#
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=PS Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 32505856
    },
    "Usage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 17715224
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 78512128,
      "init" : 64895680,
      "max" : 932118528,
      "used" : 20948536
    },
    "NonHeapMemoryUsage" : {
      "committed" : 24313856,
      "init" : 24313856,
      "max" : 138412032,
      "used" : 21287376
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "Hadoop:service=DataNode,name=DataNodeActivity-c0627-3.express.hal.cloudera.com-50010",
    "modelerType" : "DataNodeActivity-c0627-3.express.hal.cloudera.com-50010",
    "tag.SessionId" : null,
    "tag.Context" : "dfs",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "BytesWritten" : 4,
    "BytesRead" : 0,
    "BlocksWritten" : 0,
    "BlocksRead" : 0,
    "BlocksReplicated" : 0,
    "BlocksRemoved" : 0,
    "BlocksVerified" : 0,
    "BlockVerificationFailures" : 0,
    "ReadsFromLocalClient" : 0,
    "ReadsFromRemoteClient" : 8,
    "WritesFromLocalClient" : 0,
    "WritesFromRemoteClient" : 0,
    "VolumeFailures" : 0,
    "ReadBlockOpNumOps" : 0,
    "ReadBlockOpAvgTime" : 10,
    "WriteBlockOpNumOps" : 0,
    "WriteBlockOpAvgTime" : 0.0,
    "BlockChecksumOpNumOps" : 0,
    "BlockChecksumOpAvgTime" : 0.0,
    "CopyBlockOpNumOps" : 0,
    "CopyBlockOpAvgTime" : 0.0,
    "ReplaceBlockOpNumOps" : 0,
    "ReplaceBlockOpAvgTime" : 0.0,
    "HeartbeatsNumOps" : 29,
    "HeartbeatsAvgTime" : 1.8333333333333333,
    "BlockReportsNumOps" : 1,
    "BlockReportsAvgTime" : 6.0
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2654280
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2654280
    },
    "Usage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2654280
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS MarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : null,
    "CollectionCount" : 0,
    "CollectionTime" : 0,
    "Name" : "PS MarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space", "PS Old Gen", "PS Perm Gen" ]
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Server Compiler",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 2938
  }, {
    "name" : "Hadoop:service=DataNode,name=RpcActivityForPort50020",
    "modelerType" : "RpcActivityForPort50020",
    "tag.port" : "50020",
    "tag.Context" : "rpc",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "ReceivedBytes" : 0,
    "SentBytes" : 0,
    "RpcQueueTimeNumOps" : 0,
    "RpcQueueTimeAvgTime" : 0.0,
    "RpcProcessingTimeNumOps" : 0,
    "RpcProcessingTimeAvgTime" : 0.0,
    "RpcAuthenticationFailures" : 0,
    "RpcAuthenticationSuccesses" : 0,
    "RpcAuthorizationFailures" : 0,
    "RpcAuthorizationSuccesses" : 0,
    "NumOpenConnections" : 0,
    "CallQueueLength" : 0
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 1024,
    "OpenFileDescriptorCount" : 114,
    "CommittedVirtualMemorySize" : 1906274304,
    "FreePhysicalMemorySize" : 3356459008,
    "FreeSwapSpaceSize" : 3221217280,
    "ProcessCpuTime" : 86300000000,
    "TotalPhysicalMemorySize" : 4153323520,
    "TotalSwapSpaceSize" : 3221217280,
    "Name" : "Linux",
    "Version" : "2.6.32-71.29.1.el6.x86_64",
    "AvailableProcessors" : 2,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.8
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=MetricsSystem,sub=Stats",
    "modelerType" : "MetricsSystem,sub=Stats",
    "tag.Context" : "metricssystem",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "NumActiveSources" : 5,
    "NumAllSources" : 5,
    "NumActiveSinks" : 0,
    "NumAllSinks" : 0,
    "SnapshotNumOps" : 0,
    "SnapshotAvgTime" : 0.0,
    "PublishNumOps" : 0,
    "PublishAvgTime" : 0.0,
    "DroppedPubAll" : 0
  }, {
    "name" : "Hadoop:service=DataNode,name=UgiMetrics",
    "modelerType" : "UgiMetrics",
    "tag.Context" : "ugi",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "LoginSuccessNumOps" : 0,
    "LoginSuccessAvgTime" : 0.0,
    "LoginFailureNumOps" : 0,
    "LoginFailureAvgTime" : 0.0
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 2555904,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 1257664
    },
    "Usage" : {
      "committed" : 2555904,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 1160128
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "32169@c0627-3.express.hal.cloudera.com",
    "ClassPath" : "/etc/hadoop/conf:/usr/lib/hadoop/share/hadoop/common/*::/usr/lib/hadoop/hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop/hadoop-annotations.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common.jar:/usr/lib/hadoop/hadoop-yarn-site-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop/hadoop-yarn-server-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-examples.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop/hadoop-auth.jar:/usr/lib/hadoop/hadoop-auth-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-site.jar:/usr/lib/hadoop/hadoop-hdfs.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop/hadoop-yarn-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-annotations-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-nodemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api.jar:/usr/lib/hadoop/hadoop-mapreduce-examples-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/guice-servlet-2.0.jar:/usr/lib/hadoop/lib/jaxb-api-2.1.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/jetty-6.1.26.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guice-2.0.jar:/usr/lib/hadoop/lib/log4j-1.2.15.jar:/usr/lib/hadoop/lib/aopalliance-1.0.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/aspectjrt-1.6.5.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jdiff-1.0.9.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/commons-logging-api-1.1.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/core-3.1.1.jar:/usr/lib/hadoop/lib/guava-r09.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.7.1.jar:/usr/lib/hadoop/lib/stax-api-1.0-2.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/lib/clover-3.0.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/hsqldb-1.8.0.7.jar:/usr/lib/hadoop/lib/avro-ipc-1.5.3.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.7.1.jar:/usr/lib/hadoop/lib/velocity-1.5.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.7.1.jar:/usr/lib/hadoop/lib/avro-1.5.3.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.7.1.jar:/usr/lib/hadoop/lib/oro-2.0.8.jar:/usr/lib/hadoop/lib/commons-net-1.4.1.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.3.2.jar:/etc/yarn/conf:/usr/lib/hadoop/share/hadoop/hdfs/*",
    "StartTime" : 1323976807698,
    "BootClassPath" : "/usr/java/jdk1.6.0_21/jre/lib/resources.jar:/usr/java/jdk1.6.0_21/jre/lib/rt.jar:/usr/java/jdk1.6.0_21/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_21/jre/lib/jsse.jar:/usr/java/jdk1.6.0_21/jre/lib/jce.jar:/usr/java/jdk1.6.0_21/jre/lib/charsets.jar:/usr/java/jdk1.6.0_21/jre/classes",
    "LibraryPath" : "/usr/lib/hadoop/lib/native/Linux-amd64-64",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "17.0-b16",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Dproc_datanode", "-Xmx1000m", "-Dhadoop.log.dir=/var/log/hadoop", "-Dhadoop.log.file=hadoop.log", "-Dhadoop.home.dir=/usr/lib/hadoop", "-Dhadoop.id.str=hdfs", "-Dhadoop.root.logger=INFO,console", "-Djava.library.path=/usr/lib/hadoop/lib/native/Linux-amd64-64", "-Dhadoop.policy.file=hadoop-policy.xml", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.security.logger=INFO,NullAppender" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "proc_datanode",
      "value" : ""
    }, {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "hadoop.home.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "US/Pacific"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "hadoop.id.str",
      "value" : "hdfs"
    }, {
      "key" : "user.name",
      "value" : "root"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "hadoop.log.file",
      "value" : "hadoop.log"
    }, {
      "key" : "hadoop.policy.file",
      "value" : "hadoop-policy.xml"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_21/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "hadoop.log.dir",
      "value" : "/var/log/hadoop"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_21"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_21-b06"
    }, {
      "key" : "java.class.path",
      "value" : "/etc/hadoop/conf:/usr/lib/hadoop/share/hadoop/common/*::/usr/lib/hadoop/hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop/hadoop-annotations.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common.jar:/usr/lib/hadoop/hadoop-yarn-site-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop/hadoop-yarn-server-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-examples.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop/hadoop-auth.jar:/usr/lib/hadoop/hadoop-auth-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-site.jar:/usr/lib/hadoop/hadoop-hdfs.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop/hadoop-yarn-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-annotations-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-nodemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api.jar:/usr/lib/hadoop/hadoop-mapreduce-examples-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/guice-servlet-2.0.jar:/usr/lib/hadoop/lib/jaxb-api-2.1.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/jetty-6.1.26.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guice-2.0.jar:/usr/lib/hadoop/lib/log4j-1.2.15.jar:/usr/lib/hadoop/lib/aopalliance-1.0.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/aspectjrt-1.6.5.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jdiff-1.0.9.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/commons-logging-api-1.1.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/core-3.1.1.jar:/usr/lib/hadoop/lib/guava-r09.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.7.1.jar:/usr/lib/hadoop/lib/stax-api-1.0-2.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/lib/clover-3.0.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/hsqldb-1.8.0.7.jar:/usr/lib/hadoop/lib/avro-ipc-1.5.3.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.7.1.jar:/usr/lib/hadoop/lib/velocity-1.5.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.7.1.jar:/usr/lib/hadoop/lib/avro-1.5.3.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.7.1.jar:/usr/lib/hadoop/lib/oro-2.0.8.jar:/usr/lib/hadoop/lib/commons-net-1.4.1.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.3.2.jar:/etc/yarn/conf:/usr/lib/hadoop/share/hadoop/hdfs/*"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "hadoop.security.logger",
      "value" : "INFO,NullAppender"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "os.version",
      "value" : "2.6.32-71.29.1.el6.x86_64"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/resources.jar:/usr/java/jdk1.6.0_21/jre/lib/rt.jar:/usr/java/jdk1.6.0_21/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_21/jre/lib/jsse.jar:/usr/java/jdk1.6.0_21/jre/lib/jce.jar:/usr/java/jdk1.6.0_21/jre/lib/charsets.jar:/usr/java/jdk1.6.0_21/jre/classes"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "17.0-b16"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/amd64"
    }, {
      "key" : "hadoop.root.logger",
      "value" : "INFO,console"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "user.home",
      "value" : "/root"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/hadoop/lib/native/Linux-amd64-64"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Server Compiler"
    } ],
    "Uptime" : 89204
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 2559,
    "UnloadedClassCount" : 0,
    "TotalLoadedClassCount" : 2559,
    "Verbose" : false
  }, {
    "name" : "Hadoop:service=DataNode,name=DataNodeInfo",
    "modelerType" : "org.apache.hadoop.hdfs.server.datanode.DataNode",
    "Version" : "0.23.0-cdh4a1-SNAPSHOT",
    "RpcPort" : "50020",
    "HttpPort" : null,
    "NamenodeAddresses" : "{\"0.0.0.0\":\"BP-1027716416-172.29.83.240-1323975679619\"}",
    "VolumeInfo" : "{\"/tmp/hadoop-root/dfs/data/current\":{\"freeSpace\":14799339520,\"usedSpace\":24576,\"reservedSpace\":0}}",
    "ClusterId" : "CID-d77d7ba6-0758-43b2-a6e9-c16e9e33914b"
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadContentionMonitoringEnabled" : false,
    "AllThreadIds" : [ 40, 39, 36, 33, 28, 27, 26, 25, 21, 23, 16, 24, 22, 20, 19, 15, 4, 3, 2, 1 ],
    "DaemonThreadCount" : 16,
    "PeakThreadCount" : 21,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "CurrentThreadCpuTime" : 90000000,
    "CurrentThreadUserTime" : 80000000,
    "ThreadCount" : 20,
    "TotalStartedThreadCount" : 31,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "Hadoop:service=DataNode,name=RpcDetailedActivityForPort50020",
    "modelerType" : "RpcDetailedActivityForPort50020",
    "tag.port" : "50020",
    "tag.Context" : "rpcdetailed",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com"
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "sun.awt.AppContext", "javax.management", "javax.management.misc", "global", "javax.management.mbeanserver", "" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=JvmMetrics",
    "modelerType" : "JvmMetrics",
    "tag.Context" : "jvm",
    "tag.ProcessName" : "DataNode",
    "tag.SessionId" : null,
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "MemNonHeapUsedM" : 20.305374,
    "MemNonHeapCommittedM" : 23.1875,
    "MemHeapUsedM" : 20.924194,
    "MemHeapCommittedM" : 74.875,
    "GcCount" : 3,
    "GcTimeMillis" : 24,
    "ThreadsNew" : 2,
    "ThreadsRunnable" : 3,
    "ThreadsBlocked" : 1,
    "ThreadsWaiting" : 6,
    "ThreadsTimedWaiting" : 5,
    "ThreadsTerminated" : 4,
    "LogFatal" : 0,
    "LogError" : 18,
    "LogWarn" : 2,
    "LogInfo" : 47
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 21757952,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 20138168
    },
    "Usage" : {
      "committed" : 21757952,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 20138168
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "Hadoop:service=DataNode,name=MetricsSystem,sub=Control",
    "modelerType" : "org.apache.hadoop.metrics2.impl.MetricsSystemImpl"
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS Scavenge",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 2,
      "duration" : 9,
      "endTime" : 1859,
      "id" : 3,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2686976,
          "init" : 2686976,
          "max" : 2686976,
          "used" : 2654280
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 43319296,
          "init" : 43319296,
          "max" : 699072512,
          "used" : 237568
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 21757952,
          "init" : 21757952,
          "max" : 88080384,
          "used" : 17329600
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 2555904,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 1023424
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 32505856,
          "init" : 16252928,
          "max" : 344129536,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2686976,
          "init" : 2686976,
          "max" : 2686976,
          "used" : 2048096
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 43319296,
          "init" : 43319296,
          "max" : 699072512,
          "used" : 0
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 21757952,
          "init" : 21757952,
          "max" : 88080384,
          "used" : 17329600
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 2555904,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 1023424
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 32505856,
          "init" : 16252928,
          "max" : 344129536,
          "used" : 32505856
        }
      } ],
      "startTime" : 1850
    },
    "CollectionCount" : 3,
    "CollectionTime" : 24,
    "Name" : "PS Scavenge",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=FSDatasetState-DS-1376200664-172.29.83.240-50010-1323976809738",
    "modelerType" : "org.apache.hadoop.hdfs.server.datanode.FSDataset",
    "Remaining" : 14799339520,
    "DfsUsed" : 24576,
    "Capacity" : 17966100480,
    "StorageInfo" : "FSDataset{dirpath='[/tmp/hadoop-root/dfs/data/current]'}",
    "NumFailedVolumes" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 43319296,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 237568
    },
    "Usage" : {
      "committed" : 43319296,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 237568
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "c0627-3.express.hal.cloudera.com_1323976808526",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_21-b06",
    "ImplementationVendor" : "Sun Microsystems"
  } ]
}
"""
