# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

from cmf.monitor import jmx_beans
from cmf.monitor.json_metrics_utils import get_beans

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self._json = json_dict
    beans = get_beans(self._json, set([jmx_beans.NAMENODE,
                                       jmx_beans.NAMENODE_NAMESYSTEM,
                                       jmx_beans.NAMENODE_RPC,
                                       jmx_beans.NAMENODE_JVM_METRICS,
                                       jmx_beans.JAVA_MEMORY]))
    self.namenode = beans.get(jmx_beans.NAMENODE)
    self.namesystem = beans.get(jmx_beans.NAMENODE_NAMESYSTEM)
    self.rpc = beans.get(jmx_beans.NAMENODE_RPC)
    self.jvm = beans.get(jmx_beans.NAMENODE_JVM_METRICS)
    self.java_memory = beans.get(jmx_beans.JAVA_MEMORY)

#
# This is what the NN json looks like:
#
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=PS Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 32505856
    },
    "Usage" : {
      "committed" : 32505856,
      "init" : 16252928,
      "max" : 344129536,
      "used" : 20041432
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 78512128,
      "init" : 64895680,
      "max" : 932118528,
      "used" : 41222976
    },
    "NonHeapMemoryUsage" : {
      "committed" : 24313856,
      "init" : 24313856,
      "max" : 138412032,
      "used" : 22094192
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2670664
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2670664
    },
    "Usage" : {
      "committed" : 2686976,
      "init" : 2686976,
      "max" : 2686976,
      "used" : 2670664
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS MarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : null,
    "CollectionCount" : 0,
    "CollectionTime" : 0,
    "Name" : "PS MarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space", "PS Old Gen", "PS Perm Gen" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=RpcDetailedActivityForPort9000",
    "modelerType" : "RpcDetailedActivityForPort9000",
    "tag.port" : "9000",
    "tag.Context" : "rpcdetailed",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com"
  }, {
    "name" : "Hadoop:service=NameNode,name=NameNodeActivity",
    "modelerType" : "NameNodeActivity",
    "tag.ProcessName" : "NameNode",
    "tag.SessionId" : null,
    "tag.Context" : "dfs",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "CreateFileOps" : 2,
    "FilesCreated" : 0,
    "FilesAppended" : 0,
    "GetBlockLocations" : 0,
    "FilesRenamed" : 0,
    "GetListingOps" : 0,
    "DeleteFileOps" : 0,
    "FilesDeleted" : 0,
    "FileInfoOps" : 16,
    "AddBlockOps" : 0,
    "GetAdditionalDatanodeOps" : 0,
    "CreateSymlinkOps" : 0,
    "GetLinkTargetOps" : 0,
    "FilesInGetListingOps" : 0,
    "TransactionsNumOps" : 1,
    "TransactionsAvgTime" : 1.0,
    "SyncsNumOps" : 1,
    "SyncsAvgTime" : 10.0,
    "TransactionsBatchedInSync" : 0,
    "BlockReportNumOps" : 0,
    "BlockReportAvgTime" : 0.0,
    "SafeModeTime" : 1076,
    "FsImageLoadTime" : 973
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Server Compiler",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 2564
  }, {
    "name" : "Hadoop:service=NameNode,name=RpcActivityForPort9000",
    "modelerType" : "RpcActivityForPort9000",
    "tag.port" : "9000",
    "tag.Context" : "rpc",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "ReceivedBytes" : 6,
    "SentBytes" : 119,
    "RpcQueueTimeNumOps" : 0,
    "RpcQueueTimeAvgTime" : 1,
    "RpcProcessingTimeNumOps" : 0,
    "RpcProcessingTimeAvgTime" : 10,
    "RpcAuthenticationFailures" : 0,
    "RpcAuthenticationSuccesses" : 0,
    "RpcAuthorizationFailures" : 0,
    "RpcAuthorizationSuccesses" : 0,
    "NumOpenConnections" : 0,
    "CallQueueLength" : 0
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 1024,
    "OpenFileDescriptorCount" : 112,
    "CommittedVirtualMemorySize" : 1910865920,
    "FreePhysicalMemorySize" : 3439673344,
    "FreeSwapSpaceSize" : 3221217280,
    "ProcessCpuTime" : 4010000000,
    "TotalPhysicalMemorySize" : 4153323520,
    "TotalSwapSpaceSize" : 3221217280,
    "Name" : "Linux",
    "Version" : "2.6.32-71.29.1.el6.x86_64",
    "AvailableProcessors" : 2,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.12
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=UgiMetrics",
    "modelerType" : "UgiMetrics",
    "tag.Context" : "ugi",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "LoginSuccessNumOps" : 0,
    "LoginSuccessAvgTime" : 0.0,
    "LoginFailureNumOps" : 0,
    "LoginFailureAvgTime" : 0.0
  }, {
    "name" : "Hadoop:service=NameNode,name=MetricsSystem,sub=Control",
    "modelerType" : "org.apache.hadoop.metrics2.impl.MetricsSystemImpl"
  }, {
    "name" : "Hadoop:service=NameNode,name=FSNamesystemState",
    "modelerType" : "org.apache.hadoop.hdfs.server.namenode.FSNamesystem",
    "CapacityTotal" : 0,
    "CapacityUsed" : 0,
    "CapacityRemaining" : 0,
    "TotalLoad" : 0,
    "BlocksTotal" : 1,
    "FilesTotal" : 1,
    "PendingReplicationBlocks" : 0,
    "UnderReplicatedBlocks" : 0,
    "ScheduledReplicationBlocks" : 0,
    "FSState" : "Operational",
    "NumLiveDataNodes" : 0,
    "NumDeadDataNodes" : 0
  }, {
    "name" : "Hadoop:service=NameNode,name=JvmMetrics",
    "modelerType" : "JvmMetrics",
    "tag.Context" : "jvm",
    "tag.ProcessName" : "NameNode",
    "tag.SessionId" : null,
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "MemNonHeapUsedM" : 21.07122,
    "MemNonHeapCommittedM" : 23.1875,
    "MemHeapUsedM" : 39.726906,
    "MemHeapCommittedM" : 74.875,
    "GcCount" : 3,
    "GcTimeMillis" : 43,
    "ThreadsNew" : 2,
    "ThreadsRunnable" : 3,
    "ThreadsBlocked" : 1,
    "ThreadsWaiting" : 6,
    "ThreadsTimedWaiting" : 5,
    "ThreadsTerminated" : 4,
    "LogFatal" : 0,
    "LogError" : 15,
    "LogWarn" : 3,
    "LogInfo" : 67
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 2555904,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 1120960
    },
    "Usage" : {
      "committed" : 2555904,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 1045760
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "32018@c0627-3.express.hal.cloudera.com",
    "ClassPath" : "/etc/hadoop/conf:/usr/lib/hadoop/share/hadoop/common/*::/usr/lib/hadoop/hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop/hadoop-annotations.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common.jar:/usr/lib/hadoop/hadoop-yarn-site-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop/hadoop-yarn-server-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-examples.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop/hadoop-auth.jar:/usr/lib/hadoop/hadoop-auth-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-site.jar:/usr/lib/hadoop/hadoop-hdfs.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop/hadoop-yarn-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-annotations-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-nodemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api.jar:/usr/lib/hadoop/hadoop-mapreduce-examples-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/guice-servlet-2.0.jar:/usr/lib/hadoop/lib/jaxb-api-2.1.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/jetty-6.1.26.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guice-2.0.jar:/usr/lib/hadoop/lib/log4j-1.2.15.jar:/usr/lib/hadoop/lib/aopalliance-1.0.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/aspectjrt-1.6.5.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jdiff-1.0.9.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/commons-logging-api-1.1.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/core-3.1.1.jar:/usr/lib/hadoop/lib/guava-r09.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.7.1.jar:/usr/lib/hadoop/lib/stax-api-1.0-2.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/lib/clover-3.0.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/hsqldb-1.8.0.7.jar:/usr/lib/hadoop/lib/avro-ipc-1.5.3.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.7.1.jar:/usr/lib/hadoop/lib/velocity-1.5.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.7.1.jar:/usr/lib/hadoop/lib/avro-1.5.3.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.7.1.jar:/usr/lib/hadoop/lib/oro-2.0.8.jar:/usr/lib/hadoop/lib/commons-net-1.4.1.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.3.2.jar:/etc/yarn/conf:/usr/lib/hadoop/share/hadoop/hdfs/*",
    "StartTime" : 1323976598574,
    "BootClassPath" : "/usr/java/jdk1.6.0_21/jre/lib/resources.jar:/usr/java/jdk1.6.0_21/jre/lib/rt.jar:/usr/java/jdk1.6.0_21/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_21/jre/lib/jsse.jar:/usr/java/jdk1.6.0_21/jre/lib/jce.jar:/usr/java/jdk1.6.0_21/jre/lib/charsets.jar:/usr/java/jdk1.6.0_21/jre/classes",
    "LibraryPath" : "/usr/lib/hadoop/lib/native/Linux-amd64-64",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "17.0-b16",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Dproc_namenode", "-Xmx1000m", "-Dhadoop.log.dir=/var/log/hadoop", "-Dhadoop.log.file=hadoop.log", "-Dhadoop.home.dir=/usr/lib/hadoop", "-Dhadoop.id.str=hdfs", "-Dhadoop.root.logger=INFO,console", "-Djava.library.path=/usr/lib/hadoop/lib/native/Linux-amd64-64", "-Dhadoop.policy.file=hadoop-policy.xml", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.security.logger=INFO,DRFAS" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "hadoop.home.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "US/Pacific"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "hadoop.id.str",
      "value" : "hdfs"
    }, {
      "key" : "user.name",
      "value" : "root"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "hadoop.log.file",
      "value" : "hadoop.log"
    }, {
      "key" : "hadoop.policy.file",
      "value" : "hadoop-policy.xml"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_21/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "hadoop.log.dir",
      "value" : "/var/log/hadoop"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_21"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_21-b06"
    }, {
      "key" : "java.class.path",
      "value" : "/etc/hadoop/conf:/usr/lib/hadoop/share/hadoop/common/*::/usr/lib/hadoop/hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop/hadoop-annotations.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common.jar:/usr/lib/hadoop/hadoop-yarn-site-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop/hadoop-yarn-server-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app.jar:/usr/lib/hadoop/hadoop-yarn-server-web-proxy-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-examples.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop/hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop/hadoop-auth.jar:/usr/lib/hadoop/hadoop-auth-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-site.jar:/usr/lib/hadoop/hadoop-hdfs.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop/hadoop-yarn-common.jar:/usr/lib/hadoop/hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common.jar:/usr/lib/hadoop/hadoop-yarn-applications-distributedshell-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-hdfs-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-annotations-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-common-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-common-0.23.0-cdh4a1-SNAPSHOT-sources.jar:/usr/lib/hadoop/hadoop-yarn-server-nodemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-server-resourcemanager-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-app-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-yarn-api.jar:/usr/lib/hadoop/hadoop-mapreduce-examples-0.23.0-cdh4a1-SNAPSHOT.jar:/usr/lib/hadoop/hadoop-mapreduce-client-core.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/guice-servlet-2.0.jar:/usr/lib/hadoop/lib/jaxb-api-2.1.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/jetty-6.1.26.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guice-2.0.jar:/usr/lib/hadoop/lib/log4j-1.2.15.jar:/usr/lib/hadoop/lib/aopalliance-1.0.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/aspectjrt-1.6.5.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jdiff-1.0.9.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/commons-logging-api-1.1.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/core-3.1.1.jar:/usr/lib/hadoop/lib/guava-r09.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.7.1.jar:/usr/lib/hadoop/lib/stax-api-1.0-2.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/lib/clover-3.0.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/hsqldb-1.8.0.7.jar:/usr/lib/hadoop/lib/avro-ipc-1.5.3.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.7.1.jar:/usr/lib/hadoop/lib/velocity-1.5.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.7.1.jar:/usr/lib/hadoop/lib/avro-1.5.3.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.7.1.jar:/usr/lib/hadoop/lib/oro-2.0.8.jar:/usr/lib/hadoop/lib/commons-net-1.4.1.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.3.2.jar:/etc/yarn/conf:/usr/lib/hadoop/share/hadoop/hdfs/*"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "hadoop.security.logger",
      "value" : "INFO,DRFAS"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "proc_namenode",
      "value" : ""
    }, {
      "key" : "os.version",
      "value" : "2.6.32-71.29.1.el6.x86_64"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/resources.jar:/usr/java/jdk1.6.0_21/jre/lib/rt.jar:/usr/java/jdk1.6.0_21/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_21/jre/lib/jsse.jar:/usr/java/jdk1.6.0_21/jre/lib/jce.jar:/usr/java/jdk1.6.0_21/jre/lib/charsets.jar:/usr/java/jdk1.6.0_21/jre/classes"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "17.0-b16"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/amd64"
    }, {
      "key" : "hadoop.root.logger",
      "value" : "INFO,console"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_21/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "user.home",
      "value" : "/root"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/hadoop/lib/native/Linux-amd64-64"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Server Compiler"
    } ],
    "Uptime" : 98628
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 2643,
    "UnloadedClassCount" : 0,
    "TotalLoadedClassCount" : 2643,
    "Verbose" : false
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "DaemonThreadCount" : 16,
    "PeakThreadCount" : 23,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "AllThreadIds" : [ 32, 31, 30, 29, 18, 20, 28, 27, 24, 23, 16, 17, 22, 21, 19, 10, 4, 3, 2, 1 ],
    "CurrentThreadCpuTime" : 150000000,
    "CurrentThreadUserTime" : 130000000,
    "ThreadCount" : 20,
    "TotalStartedThreadCount" : 28,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "Hadoop:service=NameNode,name=FSNamesystem",
    "modelerType" : "FSNamesystem",
    "tag.Context" : "dfs",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "MissingBlocks" : 0,
    "ExpiredHeartbeats" : 0,
    "CapacityTotalGB" : 0.0,
    "CapacityUsedGB" : 0.0,
    "CapacityRemainingGB" : 0.0,
    "TotalLoad" : 0,
    "BlocksTotal" : 1,
    "FilesTotal" : 1,
    "PendingReplicationBlocks" : 0,
    "UnderReplicatedBlocks" : 0,
    "CorruptBlocks" : 0,
    "ScheduledReplicationBlocks" : 0,
    "PendingDeletionBlocks" : 0,
    "ExcessBlocks" : 0,
    "BlockCapacity" : 2097152,
    "TotalFiles" : 1
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "sun.awt.AppContext", "javax.management", "javax.management.misc", "global", "javax.management.mbeanserver", "" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=MetricsSystem,sub=Stats",
    "modelerType" : "MetricsSystem,sub=Stats",
    "tag.Context" : "metricssystem",
    "tag.Hostname" : "c0627-3.express.hal.cloudera.com",
    "NumActiveSources" : 6,
    "NumAllSources" : 6,
    "NumActiveSinks" : 0,
    "NumAllSinks" : 0,
    "SnapshotNumOps" : 0,
    "SnapshotAvgTime" : 0.0,
    "PublishNumOps" : 0,
    "PublishAvgTime" : 0.0,
    "DroppedPubAll" : 0
  }, {
    "name" : "Hadoop:service=NameNode,name=NameNodeInfo",
    "modelerType" : "org.apache.hadoop.hdfs.server.namenode.FSNamesystem",
    "Threads" : 20,
    "Total" : 0,
    "ClusterId" : "CID-d77d7ba6-0758-43b2-a6e9-c16e9e33914b",
    "BlockPoolId" : "BP-1027716416-172.29.83.240-1323975679619",
    "Used" : 0,
    "Version" : "0.23.0-cdh4a1-SNAPSHOT",
    "PercentUsed" : 100.0,
    "PercentRemaining" : 0.0,
    "Free" : 0,
    "Safemode" : "",
    "UpgradeFinalized" : true,
    "NonDfsUsedSpace" : 0,
    "BlockPoolUsedSpace" : 0,
    "PercentBlockPoolUsed" : 100.0,
    "TotalBlocks" : 0,
    "TotalFiles" : 1,
    "NumberOfMissingBlocks" : 0,
    "LiveNodes" : "{}",
    "DeadNodes" : "{}",
    "DecomNodes" : "{}"
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 21757952,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 21063272
    },
    "Usage" : {
      "committed" : 21757952,
      "init" : 21757952,
      "max" : 88080384,
      "used" : 21063272
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS Scavenge",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 2,
      "duration" : 17,
      "endTime" : 2157,
      "id" : 3,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2686976,
          "init" : 2686976,
          "max" : 2686976,
          "used" : 2670664
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 43319296,
          "init" : 43319296,
          "max" : 699072512,
          "used" : 18069760
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 21757952,
          "init" : 21757952,
          "max" : 88080384,
          "used" : 18803232
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 2555904,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 1057344
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 32505856,
          "init" : 16252928,
          "max" : 344129536,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2686976,
          "init" : 2686976,
          "max" : 2686976,
          "used" : 2277424
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 43319296,
          "init" : 43319296,
          "max" : 699072512,
          "used" : 16777240
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 21757952,
          "init" : 21757952,
          "max" : 88080384,
          "used" : 18803232
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 2555904,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 1057344
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 32505856,
          "init" : 16252928,
          "max" : 344129536,
          "used" : 32505856
        }
      } ],
      "startTime" : 2140
    },
    "CollectionCount" : 3,
    "CollectionTime" : 33,
    "Name" : "PS Scavenge",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 43319296,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 18069760
    },
    "Usage" : {
      "committed" : 43319296,
      "init" : 43319296,
      "max" : 699072512,
      "used" : 18069760
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "c0627-3.express.hal.cloudera.com_1323976599137",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_21-b06",
    "ImplementationVendor" : "Sun Microsystems"
  } ]
}
"""
