-- Copyright (c) 2011 Cloudera, Inc. All rights reserved.
--
-- Version 1 of the CMON schema. The base schema; modifications are made via
-- separate pieces of migration code.
--

-- The schema version, should be checked by the server during startup
create table CMON_SCHEMA_VERSION (
    VERSION integer not null
);

-- Update this value when the schema changes, also during migration
insert into CMON_SCHEMA_VERSION values (1);

create table CMON_METRIC_INFO (
  METRIC_ID    int not null,
  NAME         varchar(255),
  primary key (METRIC_ID)
);

create sequence SEQ_CMON_LL_TIME_SERIES_ID;
create table CMON_LL_TIME_SERIES_ID (
  ID         int not null default nextval('SEQ_CMON_LL_TIME_SERIES_ID'),
  CATEGORY   bigint,
  NAME       varchar(255),
  primary key (ID)
);
create index IDX_SERIES_BY_NAME on CMON_LL_TIME_SERIES_ID (NAME);

create sequence SEQ_CMON_LL_TIME_SERIES_ATTRIBUTE;
create table CMON_LL_TIME_SERIES_ATTRIBUTE (
  ID         bigint not null default nextval('SEQ_CMON_LL_TIME_SERIES_ATTRIBUTE'),
  ATTR_KEY   varchar(255),
  VALUE      varchar(255),
  SERIES_ID  int,
  primary key (ID),
  constraint FK_LLATTR_SERIES_ID foreign key (SERIES_ID) references CMON_LL_TIME_SERIES_ID (ID)
);
create index IDX_LLATTR_ID on CMON_LL_TIME_SERIES_ATTRIBUTE (SERIES_ID);

create sequence CMON_LL_DP_HR_SEQUENCE;
create table CMON_LL_DP_HR (
  ID          bigint not null default nextval('CMON_LL_DP_HR_SEQUENCE'),
  SERIES_ID   int,
  METRIC_ID   int,
  START_TS    bigint,
  TS          bigint,
  END_TS      bigint,
  AVERAGE     double precision,
  MINIMUM     double precision,
  MAXIMUM     double precision,
  primary key (ID),
  constraint FK_LL_HR_SERIES_ID foreign key (SERIES_ID) references CMON_LL_TIME_SERIES_ID (ID)
);
create index IDX_SERIES_METRIC_TS_HR on CMON_LL_DP_HR (SERIES_ID, METRIC_ID, TS);

create sequence CMON_LL_DP_SEQUENCE;
create table CMON_LL_DP (
  ID          bigint not null default nextval('CMON_LL_DP_SEQUENCE'),
  SERIES_ID   int,
  METRIC_ID   int,
  TS          bigint,
  VALUE       double precision,
  primary key (ID),
  constraint FK_LLRAW_SERIES_ID foreign key (SERIES_ID) references CMON_LL_TIME_SERIES_ID (ID)
);
create index IDX_SERIES_METRIC_TS_RAW on CMON_LL_DP (SERIES_ID, METRIC_ID, TS);
create index IDX_SUMMARY_CALC on CMON_LL_DP (TS);

create sequence SEQ_CMON_ACTIVITY_TIME_SERIES_ID;
create table CMON_ACTIVITY_TIME_SERIES_ID (
  ID         bigint not null default nextval('SEQ_CMON_ACTIVITY_TIME_SERIES_ID'),
  NAME       varchar(255),
  JOBID      varchar(255),
  primary key (ID)
);
create index IDX_ACTIVITY_SERIES_BY_NAME on CMON_ACTIVITY_TIME_SERIES_ID (NAME);

create sequence CMON_ACTIVITY_DP_SEQUENCE;
create table CMON_ACTIVITY_DP (
  ID          bigint not null default nextval('CMON_ACTIVITY_DP_SEQUENCE'),
  SERIES_ID   bigint,
  METRIC_ID   bigint,
  TS          bigint,
  VALUE       double precision,
  primary key (ID),
  constraint FK_ACTRAW_SERIES_ID foreign key (SERIES_ID) references CMON_ACTIVITY_TIME_SERIES_ID (ID)
);
